@@ -6,6 +6,8 @@ if(!is.na(r <- suppressWarnings(packageDescription("gmp",
                                                    fields="Version")))
    && package_version(r) >= 0.5) {
 
+
+
     ## does not work (as desired):
     ## biginteger_as_character <- gmp:::biginteger_as_character
     ## biginteger_as           <- gmp:::biginteger_as
@@ -17,12 +19,18 @@ if(!is.na(r <- suppressWarnings(packageDescription("gmp",
 ###  then use C++ with "C" { ...} for those parts
 .bigz2mpfr <- function(x) {
     stopifnot(inherits(x, "bigz"))
+    ..bigz2mpfr(x)
+}
+## Fast, no-checking (and not exported) version:
+..bigz2mpfr <- function(x, precB = 4L*nchar(cx))
+    ## precB: 4 == log2(16) = log(base)
+{
     b <- 16L
-    ## cx <- .Call(biginteger_as_character, x, b)
     cx <- .Call(gmp:::biginteger_as_character, x, b)
-    precB <- 4L*nchar(cx) # 4 == log2(16) = log(base)
     new("mpfr", .Call(str2mpfr1_list, cx, precB, b, "N"))
 }
+setAs("bigz", "mpfr", function(from) ..bigz2mpfr(from))
+
 
 as.bigz.mpfr <-
 .mpfr2bigz <- function(x, mod=NA) {
@@ -36,4 +44,15 @@ as.bigz.mpfr <-
     .Call(gmp:::biginteger_as, cx, mod)
 }
 
+
+.bigq2mpfr <- function(from) {
+    stopifnot(inherits(from, "bigq"))
+    eN <- frexpZ(N <- numerator(from))$exp
+    eD <- frexpZ(D <- denominator(from))$exp
+    precRes <- eN + eD + 1L # precision of result
+    ..bigz2mpfr(N, precRes) / ..bigz2mpfr(D, precRes)
+}
+setAs("bigq", "mpfr", .bigq2mpfr)
+
+
 }# only if gmp ..
